@@ -6,12 +6,11 @@ import threading
 import time
 import os
 import sqlite3
+import subprocess
 import sys
-import json as _json
-import urllib.request as _urlreq
-import shutil as _shutil
-import subprocess as _subprocess
-from importlib import metadata as _metadata
+import shutil
+import requests
+import json
 
 from .database import TimeTrackerDB
 from .pdf_export import PDFExporter
@@ -26,7 +25,6 @@ class TimeTrackerGUI:
         self.root = tk.Tk()
         self.root.title("Time Tracker")
         self.root.geometry("900x700")
-        
         # Ensure tkinter default root is set (helps tests with mocked Tk)
         try:
             if getattr(tk, "_default_root", None) is None:
@@ -34,11 +32,6 @@ class TimeTrackerGUI:
         except Exception:
             pass
         
-        # Handle window close button (X) properly
-        self.root.protocol("WM_DELETE_WINDOW", self.on_closing)
-        
-        # Icon handling removed
-        
         # Timer variables
         self.current_timer = None
         self.timer_running = False
@@ -50,13 +43,6 @@ class TimeTrackerGUI:
     
     def setup_ui(self):
         """Setup the main UI"""
-        # Menubar
-        menubar = tk.Menu(self.root)
-        help_menu = tk.Menu(menubar, tearoff=0)
-        help_menu.add_command(label="Check for Updates", command=self.check_for_updates)
-        menubar.add_cascade(label="Help", menu=help_menu)
-        self.root.config(menu=menubar)
-
         # Main frame
         main_frame = ttk.Frame(self.root, padding="10")
         main_frame.grid(row=0, column=0, sticky=(tk.W, tk.E, tk.N, tk.S))
@@ -490,129 +476,6 @@ class TimeTrackerGUI:
             
             self.root.after(0, lambda: self.timer_label.config(text=time_str))
             time.sleep(1)
-
-    # ====== Update / Upgrade utilities ======
-    def check_for_updates(self):
-        """Check PyPI for a newer version and prompt to update."""
-        try:
-            current_version = _metadata.version("timetracking")
-        except Exception:
-            current_version = "0.0.0"
-
-        latest = None
-        try:
-            with _urlreq.urlopen("https://pypi.org/pypi/timetracking/json", timeout=5) as resp:
-                data = resp.read()
-            info = _json.loads(data.decode("utf-8"))
-            latest = info.get("info", {}).get("version")
-        except Exception:
-            messagebox.showerror("Update", "Unable to check for updates right now.")
-            return
-
-        if not latest:
-            messagebox.showerror("Update", "Could not determine latest version.")
-            return
-
-        # Debug output
-        #
-
-        if self._version_tuple(latest) <= self._version_tuple(current_version):
-            messagebox.showinfo("Update", f"You are up to date (v{current_version}).")
-            return
-
-        if not messagebox.askyesno("Update Available", f"A new version is available (v{latest}).\n\nCurrent: v{current_version}\n\nUpdate now?"):
-            return
-
-        # Run upgrade on background thread with target version
-        threading.Thread(target=self._run_upgrade_and_prompt_restart, args=(latest,), daemon=True).start()
-
-    def _version_tuple(self, v: str):
-        return tuple(int(p) if p.isdigit() else 0 for p in v.replace("-", ".").split("."))
-
-    def _run_upgrade_and_prompt_restart(self, target_version=None):
-        """Attempt to upgrade via pipx first, then pip; prompt to restart."""
-        ok, output = self._attempt_upgrade(target_version)
-        self.root.after(0, lambda: self._post_upgrade_dialog(ok, output, target_version))
-
-    def _post_upgrade_dialog(self, ok: bool, output: str, target_version=None):
-        if ok:
-            # Verify the installed version matches target
-            if target_version:
-                try:
-                    installed_version = _metadata.version("timetracking")
-                    if self._version_tuple(installed_version) < self._version_tuple(target_version):
-                        # Version still behind, try one more time with exact version
-                        threading.Thread(target=self._run_upgrade_and_prompt_restart, args=(target_version,), daemon=True).start()
-                        return
-                except Exception:
-                    pass  # Continue with restart if verification fails
-            
-            if messagebox.askyesno("Update", "Update completed. Restart the app now?"):
-                self._restart_app()
-        else:
-            messagebox.showerror("Update Failed", f"The update did not complete.\n\nDetails:\n{output[:2000]}")
-
-    def _attempt_upgrade(self, target_version=None):
-        """Upgrade to the exact target version without cache to avoid double-update issues."""
-        cmds = []
-        
-        if target_version:
-            # Install exact version without cache
-            if _shutil.which("pipx"):
-                cmds.append(["pipx", "install", f"timetracking=={target_version}", "--pip-args=--no-cache-dir"])
-            cmds.append([sys.executable, "-m", "pip", "install", "--no-cache-dir", f"timetracking=={target_version}"])
-        else:
-            # Fallback to general upgrade
-            if _shutil.which("pipx"):
-                cmds.append(["pipx", "upgrade", "timetracking"])
-            cmds.append([sys.executable, "-m", "pip", "install", "-U", "timetracking"])
-
-        last_out = ""
-        for cmd in cmds:
-            try:
-                proc = _subprocess.run(cmd, stdout=_subprocess.PIPE, stderr=_subprocess.STDOUT, text=True)
-                if proc.returncode == 0:
-                    return True, proc.stdout
-                last_out = proc.stdout
-            except Exception as e:
-                last_out = str(e)
-        return False, last_out
-
-    def _restart_app(self):
-        """Restart the application using the console entry-point."""
-        try:
-            import os
-            import shutil
-            
-            # Try multiple restart methods
-            restart_commands = []
-            
-            # Method 1: Use pipx command if available
-            timetracking_cmd = shutil.which('timetracking')
-            if timetracking_cmd:
-                restart_commands.append(['timetracking'])
-            
-            # Method 2: Try to find the pipx executable and run timetracking through it
-            pipx_cmd = shutil.which('pipx')
-            if pipx_cmd:
-                restart_commands.append([pipx_cmd, 'run', 'timetracking'])
-            
-            # Method 3: Fallback to direct module execution
-            restart_commands.append([sys.executable, "-m", "timetracking"])
-            
-            # Try each method until one works
-            for cmd in restart_commands:
-                try:
-                    _subprocess.Popen(cmd, stdout=_subprocess.DEVNULL, stderr=_subprocess.DEVNULL)
-                    break
-                except Exception as e:
-                    pass
-                    continue
-                    
-        except Exception as e:
-            pass
-        finally:
-            self.root.quit()
     
     def on_filter_change(self, event=None):
         """Handle filter changes"""
@@ -695,9 +558,9 @@ class TimeTrackerGUI:
             except:
                 pass
         
-        # Create email dialog
-        email_dialog = EmailDialog(self.root, self.db, self.pdf_exporter, self.email_exporter, project_emails)
-        self.root.wait_window(email_dialog.dialog)
+        # Create weekly report dialog with reflection
+        weekly_dialog = WeeklyReportDialog(self.root, self.db, self.pdf_exporter, self.email_exporter, project_emails)
+        self.root.wait_window(weekly_dialog.dialog)
     
     def edit_entry(self):
         """Edit selected time entry"""
@@ -736,18 +599,120 @@ class TimeTrackerGUI:
             else:
                 messagebox.showerror("Error", "Failed to delete entry")
     
-    # Icon helpers removed
-
-    def on_closing(self):
-        """Handle window close event"""
-        # Stop any running timer
-        if self.timer_running:
-            self.timer_running = False
-        # Destroy the window and exit
-        self.root.destroy()
-        # Force exit the application
-        import sys
-        sys.exit(0)
+    def check_for_updates(self):
+        """Check for updates from PyPI"""
+        try:
+            # Get current version
+            current_version = self._get_current_version()
+            if not current_version:
+                messagebox.showerror("Error", "Could not determine current version")
+                return
+            
+            # Get latest version from PyPI
+            latest_version = self._get_latest_version()
+            if not latest_version:
+                messagebox.showerror("Error", "Could not check for updates. Please check your internet connection.")
+                return
+            
+            # Compare versions
+            if self._version_tuple(current_version) < self._version_tuple(latest_version):
+                self._run_upgrade_and_prompt_restart(latest_version)
+            else:
+                messagebox.showinfo("Updates", f"You are running the latest version ({current_version})")
+        
+        except Exception as e:
+            messagebox.showerror("Error", f"Failed to check for updates: {str(e)}")
+    
+    def _get_current_version(self):
+        """Get current version from package metadata"""
+        try:
+            import pkg_resources
+            return pkg_resources.get_distribution("timetracking").version
+        except:
+            # Fallback to reading from setup.py or pyproject.toml
+            try:
+                with open("pyproject.toml", "r") as f:
+                    content = f.read()
+                    for line in content.split("\n"):
+                        if line.strip().startswith("version ="):
+                            return line.split("=")[1].strip().strip('"')
+            except:
+                return "1.0.39"  # Fallback version
+    
+    def _get_latest_version(self):
+        """Get latest version from PyPI"""
+        try:
+            response = requests.get("https://pypi.org/pypi/timetracking/json", timeout=10)
+            if response.status_code == 200:
+                data = response.json()
+                return data["info"]["version"]
+            return None
+        except:
+            return None
+    
+    def _version_tuple(self, version_str):
+        """Convert version string to tuple for comparison"""
+        try:
+            return tuple(map(int, version_str.split(".")))
+        except:
+            return (0, 0, 0)
+    
+    def _run_upgrade_and_prompt_restart(self, target_version):
+        """Run upgrade and prompt for restart"""
+        result = messagebox.askyesno(
+            "Update Available", 
+            f"Version {target_version} is available. Would you like to update now?"
+        )
+        
+        if result:
+            if self._attempt_upgrade(target_version):
+                self._post_upgrade_dialog(target_version)
+            else:
+                messagebox.showerror("Update Failed", "Failed to update. Please try again later.")
+    
+    def _attempt_upgrade(self, target_version):
+        """Attempt to upgrade the package"""
+        try:
+            # Check if running under pipx
+            if shutil.which('timetracking'):
+                # Running under pipx
+                cmd = ['pipx', 'upgrade', 'timetracking']
+            else:
+                # Running under regular pip
+                cmd = [sys.executable, '-m', 'pip', 'install', '--upgrade', '--no-cache-dir', f'timetracking=={target_version}']
+            
+            result = subprocess.run(cmd, capture_output=True, text=True, timeout=120)
+            return result.returncode == 0
+        except Exception as e:
+            print(f"Upgrade failed: {e}")
+            return False
+    
+    def _post_upgrade_dialog(self, target_version):
+        """Show dialog after upgrade"""
+        result = messagebox.askyesno(
+            "Restart Required", 
+            f"Update to version {target_version} completed. Restart the application now?"
+        )
+        
+        if result:
+            self._restart_app()
+    
+    def _restart_app(self):
+        """Restart the application"""
+        try:
+            # Check if running under pipx
+            if shutil.which('timetracking'):
+                # Running under pipx
+                subprocess.Popen(['timetracking'])
+            else:
+                # Running under regular python
+                subprocess.Popen([sys.executable, '-m', 'timetracking'])
+            
+            # Close current application
+            self.root.quit()
+            sys.exit(0)
+        except Exception as e:
+            messagebox.showerror("Error", f"Failed to restart: {str(e)}")
     
     def run(self):
         """Start the GUI application"""
@@ -838,8 +803,6 @@ class EmailDialog:
         ttk.Button(button_frame, text="Send", command=self.send_email_report).pack(side=tk.LEFT, padx=(0, 5))
         ttk.Button(button_frame, text="Email Settings", command=self.open_settings).pack(side=tk.LEFT, padx=(0, 5))
         ttk.Button(button_frame, text="Cancel", command=self.dialog.destroy).pack(side=tk.LEFT)
-
-    # Removed duplicate update utilities from EmailDialog; handled by TimeTrackerGUI.
     
     
     def open_settings(self):
@@ -910,7 +873,7 @@ class EmailDialog:
                     if success:
                         success_count += 1
                 except Exception as e:
-                    pass
+                    print(f"Failed to send to {recipient}: {str(e)}")
             
             if success_count > 0:
                 messagebox.showinfo("Success", f"Email sent successfully to {success_count} recipient(s)!")
@@ -1206,25 +1169,10 @@ class EditEntryDialog:
         main_frame = ttk.Frame(self.dialog, padding="10")
         main_frame.pack(fill=tk.BOTH, expand=True)
         
-        # Debug: Print entry data
-        print(f"DEBUG: EditEntryDialog - Entry data: {self.entry}")
-        print(f"DEBUG: EditEntryDialog - Entry length: {len(self.entry) if self.entry else 'None'}")
-        
-        # Validate entry data
-        if not self.entry or len(self.entry) < 6:
-            print(f"DEBUG: EditEntryDialog - Invalid entry data: {self.entry}")
-            messagebox.showerror("Error", "Invalid entry data")
-            self.dialog.destroy()
-            return
-        
         # Entry ID (read-only)
         ttk.Label(main_frame, text="Entry ID:").grid(row=0, column=0, sticky=tk.W, pady=(0, 5))
-        entry_id_value = str(self.entry[0])
-        print(f"DEBUG: EditEntryDialog - Entry ID value: '{entry_id_value}'")
-        self.entry_id_var = tk.StringVar(value=entry_id_value)
-        self.entry_id_widget = ttk.Entry(main_frame, textvariable=self.entry_id_var, state="readonly", width=20)
-        self.entry_id_widget.grid(row=0, column=1, sticky=(tk.W, tk.E), pady=(0, 5))
-        print(f"DEBUG: EditEntryDialog - Entry ID widget created, value: '{self.entry_id_var.get()}'")
+        self.entry_id_var = tk.StringVar(value=str(self.entry[0]))
+        ttk.Entry(main_frame, textvariable=self.entry_id_var, state="readonly", width=20).grid(row=0, column=1, sticky=(tk.W, tk.E), pady=(0, 5))
         
         # Project (selectable)
         ttk.Label(main_frame, text="Project:").grid(row=1, column=0, sticky=tk.W, pady=(0, 5))
@@ -1245,23 +1193,14 @@ class EditEntryDialog:
         
         # Description
         ttk.Label(main_frame, text="Description:").grid(row=2, column=0, sticky=tk.W, pady=(0, 5))
-        description_value = self.entry[3] or ""
-        print(f"DEBUG: EditEntryDialog - Description value: '{description_value}'")
-        self.description_var = tk.StringVar(value=description_value)
-        self.description_widget = ttk.Entry(main_frame, textvariable=self.description_var, width=40)
-        self.description_widget.grid(row=2, column=1, sticky=(tk.W, tk.E), pady=(0, 5))
-        print(f"DEBUG: EditEntryDialog - Description widget created, value: '{self.description_var.get()}'")
+        self.description_var = tk.StringVar(value=self.entry[3] or "")
+        ttk.Entry(main_frame, textvariable=self.description_var, width=40).grid(row=2, column=1, sticky=(tk.W, tk.E), pady=(0, 5))
         
         # Start time
         ttk.Label(main_frame, text="Start Time:").grid(row=3, column=0, sticky=tk.W, pady=(0, 5))
-        start_time_value = self.entry[4]
-        print(f"DEBUG: EditEntryDialog - Start time value: '{start_time_value}'")
-        start_dt = datetime.fromisoformat(start_time_value)
-        start_date_str = start_dt.strftime('%Y-%m-%d')
-        start_time_str = start_dt.strftime('%H:%M:%S')
-        print(f"DEBUG: EditEntryDialog - Start date: '{start_date_str}', Start time: '{start_time_str}'")
-        self.start_date_var = tk.StringVar(value=start_date_str)
-        self.start_time_var = tk.StringVar(value=start_time_str)
+        start_dt = datetime.fromisoformat(self.entry[4])
+        self.start_date_var = tk.StringVar(value=start_dt.strftime('%Y-%m-%d'))
+        self.start_time_var = tk.StringVar(value=start_dt.strftime('%H:%M:%S'))
         
         start_frame = ttk.Frame(main_frame)
         start_frame.grid(row=3, column=1, sticky=(tk.W, tk.E), pady=(0, 5))
@@ -1274,17 +1213,11 @@ class EditEntryDialog:
         
         # End time
         ttk.Label(main_frame, text="End Time:").grid(row=4, column=0, sticky=tk.W, pady=(0, 5))
-        if self.entry[5] and self.entry[5].strip():  # If end_time exists and is not empty
-            end_time_value = self.entry[5]
-            print(f"DEBUG: EditEntryDialog - End time value: '{end_time_value}'")
-            end_dt = datetime.fromisoformat(end_time_value)
-            end_date_str = end_dt.strftime('%Y-%m-%d')
-            end_time_str = end_dt.strftime('%H:%M:%S')
-            print(f"DEBUG: EditEntryDialog - End date: '{end_date_str}', End time: '{end_time_str}'")
-            self.end_date_var = tk.StringVar(value=end_date_str)
-            self.end_time_var = tk.StringVar(value=end_time_str)
+        if self.entry[5]:  # If end_time exists
+            end_dt = datetime.fromisoformat(self.entry[5])
+            self.end_date_var = tk.StringVar(value=end_dt.strftime('%Y-%m-%d'))
+            self.end_time_var = tk.StringVar(value=end_dt.strftime('%H:%M:%S'))
         else:
-            print(f"DEBUG: EditEntryDialog - No end time, setting empty values")
             self.end_date_var = tk.StringVar(value="")
             self.end_time_var = tk.StringVar(value="")
         
@@ -1307,19 +1240,6 @@ class EditEntryDialog:
         # Calculate initial duration
         self.update_duration()
         
-        # Debug: Check StringVar values after all widgets are created
-        print(f"DEBUG: EditEntryDialog - Final StringVar values:")
-        print(f"  Entry ID: '{self.entry_id_var.get()}'")
-        print(f"  Description: '{self.description_var.get()}'")
-        print(f"  Start Date: '{self.start_date_var.get()}'")
-        print(f"  Start Time: '{self.start_time_var.get()}'")
-        print(f"  End Date: '{self.end_date_var.get()}'")
-        print(f"  End Time: '{self.end_time_var.get()}'")
-        print(f"  Duration: '{self.duration_var.get()}'")
-        
-        # Force UI update after a short delay
-        self.dialog.after(100, self._force_ui_update)
-        
         # Help text
         help_text = "Date format: YYYY-MM-DD\nTime format: HH:MM:SS\nLeave end time empty for running timers"
         ttk.Label(main_frame, text=help_text, font=("Arial", 8)).grid(row=6, column=0, columnspan=2, sticky=tk.W, pady=(10, 0))
@@ -1331,40 +1251,6 @@ class EditEntryDialog:
         ttk.Button(button_frame, text="Save", command=self.save_entry).pack(side=tk.LEFT, padx=(0, 5))
         ttk.Button(button_frame, text="Cancel", command=self.dialog.destroy).pack(side=tk.LEFT)
     
-    def _force_ui_update(self):
-        """Force UI update to ensure StringVar values are displayed"""
-        print("DEBUG: EditEntryDialog - Forcing UI update")
-        print(f"  Entry ID after update: '{self.entry_id_var.get()}'")
-        print(f"  Description after update: '{self.description_var.get()}'")
-        print(f"  Start Date after update: '{self.start_date_var.get()}'")
-        print(f"  Start Time after update: '{self.start_time_var.get()}'")
-        print(f"  End Date after update: '{self.end_date_var.get()}'")
-        print(f"  End Time after update: '{self.end_time_var.get()}'")
-        print(f"  Duration after update: '{self.duration_var.get()}'")
-        
-        # Try alternative approach: directly set Entry widget values
-        print("DEBUG: EditEntryDialog - Trying direct widget value setting")
-        try:
-            # Find and update Entry widgets directly
-            for widget in self.dialog.winfo_children():
-                if isinstance(widget, ttk.Frame):
-                    for child in widget.winfo_children():
-                        if isinstance(child, ttk.Entry):
-                            if hasattr(child, 'cget') and child.cget('textvariable') == str(self.entry_id_var):
-                                child.delete(0, tk.END)
-                                child.insert(0, self.entry_id_var.get())
-                                print(f"  Directly set Entry ID widget: '{child.get()}'")
-                            elif hasattr(child, 'cget') and child.cget('textvariable') == str(self.description_var):
-                                child.delete(0, tk.END)
-                                child.insert(0, self.description_var.get())
-                                print(f"  Directly set Description widget: '{child.get()}'")
-        except Exception as e:
-            print(f"  Error in direct widget setting: {e}")
-        
-        # Force the dialog to update
-        self.dialog.update_idletasks()
-        self.dialog.update()
-    
     def update_duration(self, *args):
         """Update the duration display when time fields change"""
         try:
@@ -1472,6 +1358,320 @@ class EditEntryDialog:
         except Exception as e:
             messagebox.showerror("Error", f"Failed to update entry: {e}")
 
+class WeeklyReportDialog:
+    def __init__(self, parent, db, pdf_exporter, email_exporter, project_emails=None):
+        self.db = db
+        self.pdf_exporter = pdf_exporter
+        self.email_exporter = email_exporter
+        self.project_emails = project_emails or []
+        
+        self.dialog = tk.Toplevel(parent)
+        self.dialog.title("Weekly Report with Reflection")
+        self.dialog.geometry("800x700")
+        self.dialog.transient(parent)
+        self.dialog.grab_set()
+        
+        # Center the dialog
+        self.dialog.geometry("+%d+%d" % (parent.winfo_rootx() + 50, parent.winfo_rooty() + 50))
+        
+        self.setup_ui()
+    
+    def setup_ui(self):
+        """Setup weekly report dialog UI"""
+        main_frame = ttk.Frame(self.dialog, padding="10")
+        main_frame.pack(fill=tk.BOTH, expand=True)
+        
+        # Check if email settings are configured
+        if not self.email_exporter.sender_email or not self.email_exporter.sender_password:
+            ttk.Label(main_frame, text="Email settings not configured!", font=("Arial", 12, "bold"), foreground="red").grid(row=0, column=0, columnspan=2, sticky=tk.W, pady=(0, 10))
+            ttk.Label(main_frame, text="Please configure your email settings first.").grid(row=1, column=0, columnspan=2, sticky=tk.W, pady=(0, 20))
+            
+            button_frame = ttk.Frame(main_frame)
+            button_frame.grid(row=2, column=0, columnspan=2, pady=(20, 0))
+            ttk.Button(button_frame, text="Configure Email Settings", command=self.open_settings).pack(side=tk.LEFT, padx=(0, 5))
+            ttk.Button(button_frame, text="Cancel", command=self.dialog.destroy).pack(side=tk.LEFT)
+            return
+        
+        # Email settings are configured
+        ttk.Label(main_frame, text=f"From: {self.email_exporter.sender_email}", font=("Arial", 10, "bold")).grid(row=0, column=0, columnspan=2, sticky=tk.W, pady=(0, 10))
+        
+        # Recipient emails section
+        ttk.Label(main_frame, text="Recipient Emails:", font=("Arial", 10, "bold")).grid(row=1, column=0, columnspan=2, sticky=tk.W, pady=(0, 5))
+        
+        # Email selection frame with checkboxes
+        email_frame = ttk.Frame(main_frame)
+        email_frame.grid(row=2, column=0, columnspan=2, sticky=(tk.W, tk.E), pady=(0, 10))
+        
+        # Create checkboxes for each project email
+        self.email_checkboxes = {}
+        self.email_vars = {}
+        
+        if self.project_emails:
+            ttk.Label(email_frame, text="Select recipients:", font=("Arial", 9, "bold")).grid(row=0, column=0, sticky=tk.W, pady=(0, 5))
+            
+            for i, (email_id, email, is_primary) in enumerate(self.project_emails):
+                # Create checkbox variable
+                var = tk.BooleanVar(value=is_primary)  # Pre-select primary emails
+                self.email_vars[email_id] = var
+                
+                # Create checkbox with label
+                checkbox = ttk.Checkbutton(
+                    email_frame, 
+                    text=f"{email} {'(Primary)' if is_primary else ''}",
+                    variable=var
+                )
+                checkbox.grid(row=i+1, column=0, sticky=tk.W, pady=2)
+                self.email_checkboxes[email_id] = checkbox
+        else:
+            ttk.Label(email_frame, text="No project emails configured", font=("Arial", 9), foreground="gray").grid(row=0, column=0, sticky=tk.W, pady=(0, 5))
+        
+        # Custom email entry
+        ttk.Label(main_frame, text="Custom Email:").grid(row=3, column=0, sticky=tk.W, pady=(10, 5))
+        self.custom_email = tk.StringVar()
+        ttk.Entry(main_frame, textvariable=self.custom_email, width=40).grid(row=3, column=1, sticky=(tk.W, tk.E), pady=(10, 5))
+        
+        # Weekly Reflection Section
+        ttk.Label(main_frame, text="Weekly Reflection (MSE Requirement):", font=("Arial", 10, "bold")).grid(row=4, column=0, columnspan=2, sticky=tk.W, pady=(20, 5))
+        
+        # Reflection template
+        reflection_template = """• Key achievements this week:
+• Challenges encountered:
+• Lessons learned:
+• Goals for next week:
+• Additional observations:"""
+        
+        ttk.Label(main_frame, text="Please reflect on your week using the template below:", font=("Arial", 9)).grid(row=5, column=0, columnspan=2, sticky=tk.W, pady=(0, 5))
+        
+        # Reflection text area
+        reflection_frame = ttk.Frame(main_frame)
+        reflection_frame.grid(row=6, column=0, columnspan=2, sticky=(tk.W, tk.E, tk.N, tk.S), pady=(0, 10))
+        
+        self.reflection_text = tk.Text(reflection_frame, height=8, width=70, wrap=tk.WORD)
+        scrollbar = ttk.Scrollbar(reflection_frame, orient=tk.VERTICAL, command=self.reflection_text.yview)
+        self.reflection_text.configure(yscrollcommand=scrollbar.set)
+        
+        self.reflection_text.pack(side=tk.LEFT, fill=tk.BOTH, expand=True)
+        scrollbar.pack(side=tk.RIGHT, fill=tk.Y)
+        
+        # Insert template
+        self.reflection_text.insert(tk.END, reflection_template)
+        
+        # Options
+        ttk.Label(main_frame, text="Options:").grid(row=7, column=0, sticky=tk.W, pady=(10, 5))
+        
+        self.include_pdf = tk.BooleanVar(value=True)
+        ttk.Checkbutton(main_frame, text="Include PDF attachment", variable=self.include_pdf).grid(row=8, column=0, columnspan=2, sticky=tk.W, pady=(0, 5))
+        
+        # Buttons
+        button_frame = ttk.Frame(main_frame)
+        button_frame.grid(row=9, column=0, columnspan=2, pady=(20, 0))
+        
+        ttk.Button(button_frame, text="Send Weekly Report", command=self.send_weekly_report).pack(side=tk.LEFT, padx=(0, 5))
+        ttk.Button(button_frame, text="Email Settings", command=self.open_settings).pack(side=tk.LEFT, padx=(0, 5))
+        ttk.Button(button_frame, text="Cancel", command=self.dialog.destroy).pack(side=tk.LEFT)
+    
+    def open_settings(self):
+        """Open email settings dialog"""
+        settings_dialog = EmailSettingsDialog(self.dialog, self.email_exporter)
+        self.dialog.wait_window(settings_dialog.dialog)
+        
+        # After settings dialog closes, refresh the dialog
+        self.refresh_dialog()
+    
+    def refresh_dialog(self):
+        """Refresh the dialog after settings are updated"""
+        # Reload email configuration
+        self.email_exporter.load_config()
+        
+        # Destroy and recreate the dialog
+        self.dialog.destroy()
+        # Note: This will require the parent to recreate the dialog
+    
+    def send_weekly_report(self):
+        """Send the weekly report with reflection"""
+        # Get selected emails from checkboxes
+        selected_emails = []
+        for email_id, var in self.email_vars.items():
+            if var.get():  # Checkbox is selected
+                # Find the email address for this ID
+                for proj_email_id, email, is_primary in self.project_emails:
+                    if proj_email_id == email_id:
+                        selected_emails.append(email)
+                        break
+        
+        # Get custom email
+        custom_email = self.custom_email.get().strip()
+        if custom_email:
+            selected_emails.append(custom_email)
+        
+        if not selected_emails:
+            messagebox.showerror("Error", "Please select at least one email or enter a custom email")
+            return
+        
+        # Get reflection text
+        reflection_content = self.reflection_text.get("1.0", tk.END).strip()
+        if not reflection_content or reflection_content == "• Key achievements this week:\n• Challenges encountered:\n• Lessons learned:\n• Goals for next week:\n• Additional observations:":
+            messagebox.showerror("Error", "Please provide your weekly reflection")
+            return
+        
+        try:
+            # Get time entries for the current week
+            today = datetime.now().date()
+            start_of_week = today - timedelta(days=today.weekday())
+            end_of_week = start_of_week + timedelta(days=6)
+            
+            # Get entries for the week
+            entries = self.db.get_time_entries()
+            weekly_entries = []
+            for entry in entries:
+                entry_date = datetime.fromisoformat(entry[4]).date()  # start_time
+                if start_of_week <= entry_date <= end_of_week:
+                    weekly_entries.append(entry)
+            
+            if not weekly_entries:
+                messagebox.showwarning("Warning", "No time entries found for this week")
+                return
+            
+            # Create email content with reflection
+            subject = f"Weekly Report - Week of {start_of_week.strftime('%B %d, %Y')}"
+            
+            # Generate timesheet content
+            timesheet_content = self.generate_timesheet_content(weekly_entries)
+            
+            # Combine timesheet and reflection
+            email_body = f"""Dear Professor,
+
+Please find attached my weekly timesheet for the week of {start_of_week.strftime('%B %d, %Y')}.
+
+{timesheet_content}
+
+WEEKLY REFLECTION:
+{reflection_content}
+
+Best regards,
+Student"""
+            
+            # Send email using the existing send_time_report method
+            # We need to create a custom email with the reflection content
+            success = self.send_custom_email(
+                selected_emails,
+                subject,
+                email_body,
+                weekly_entries if self.include_pdf.get() else None
+            )
+            
+            if success:
+                messagebox.showinfo("Success", "Weekly report sent successfully!")
+                self.dialog.destroy()
+            else:
+                messagebox.showerror("Error", "Failed to send weekly report")
+                
+        except Exception as e:
+            messagebox.showerror("Error", f"Failed to send weekly report: {str(e)}")
+    
+    def generate_timesheet_content(self, entries):
+        """Generate timesheet content for email"""
+        content = "TIMESHEET SUMMARY:\n\n"
+        
+        total_hours = 0
+        for entry in entries:
+            entry_id, project_id, project_name, description, start_time, end_time, duration, rate, currency = entry
+            
+            # Format dates and times
+            start_dt = datetime.fromisoformat(start_time)
+            date_str = start_dt.strftime('%Y-%m-%d')
+            start_time_str = start_dt.strftime('%H:%M')
+            
+            if end_time:
+                end_dt = datetime.fromisoformat(end_time)
+                end_time_str = end_dt.strftime('%H:%M')
+            else:
+                end_time_str = "Running"
+            
+            # Format duration
+            if duration is not None:
+                hours = duration // 60
+                minutes = duration % 60
+                if hours > 0:
+                    duration_str = f"{hours}h {minutes}m"
+                else:
+                    duration_str = f"{minutes}m"
+                total_hours += duration / 60.0
+            else:
+                duration_str = "Running"
+            
+            content += f"Date: {date_str}\n"
+            content += f"Project: {project_name}\n"
+            content += f"Description: {description or 'N/A'}\n"
+            content += f"Time: {start_time_str} - {end_time_str}\n"
+            content += f"Duration: {duration_str}\n\n"
+        
+        content += f"Total Hours: {total_hours:.1f}\n"
+        return content
+    
+    def send_custom_email(self, recipients, subject, body, time_entries=None):
+        """Send custom email with optional PDF attachment"""
+        try:
+            import smtplib
+            from email.mime.text import MIMEText
+            from email.mime.multipart import MIMEMultipart
+            from email.mime.base import MIMEBase
+            from email import encoders
+            import tempfile
+            import os
+            
+            # Create message
+            msg = MIMEMultipart()
+            msg['From'] = self.email_exporter.sender_email
+            msg['To'] = ', '.join(recipients)
+            msg['Subject'] = subject
+            
+            # Add body
+            msg.attach(MIMEText(body, 'plain'))
+            
+            # Add PDF attachment if requested and entries provided
+            if time_entries and self.include_pdf.get():
+                try:
+                    # Create temporary PDF
+                    with tempfile.NamedTemporaryFile(suffix='.pdf', delete=False) as temp_file:
+                        pdf_path = temp_file.name
+                    
+                    # Generate PDF
+                    self.pdf_exporter.export_time_report(time_entries, pdf_path)
+                    
+                    # Attach PDF
+                    with open(pdf_path, "rb") as attachment:
+                        part = MIMEBase('application', 'octet-stream')
+                        part.set_payload(attachment.read())
+                    
+                    encoders.encode_base64(part)
+                    part.add_header(
+                        'Content-Disposition',
+                        f'attachment; filename= weekly_report.pdf'
+                    )
+                    msg.attach(part)
+                    
+                    # Clean up temp file
+                    os.unlink(pdf_path)
+                    
+                except Exception as e:
+                    print(f"Warning: Could not attach PDF: {e}")
+            
+            # Send email
+            server = smtplib.SMTP(self.email_exporter.smtp_server, self.email_exporter.smtp_port)
+            server.starttls()
+            server.login(self.email_exporter.sender_email, self.email_exporter.sender_password)
+            
+            text = msg.as_string()
+            server.sendmail(self.email_exporter.sender_email, recipients, text)
+            server.quit()
+            
+            return True
+            
+        except Exception as e:
+            print(f"Email sending failed: {e}")
+            return False
+
 class EmailSettingsDialog:
     def __init__(self, parent, email_exporter):
         self.email_exporter = email_exporter
