@@ -6,18 +6,11 @@ A Python-based time tracking application with GUI, SQLite database, and PDF/Emai
 
 import sys
 import os
-from timetracking.gui import TimeTrackerGUI
-import tkinter as tk
+from .gui import TimeTrackerGUI
 
 def main():
     """Main entry point for the Time Tracker application"""
     try:
-        # Ensure a Tk root exists before GUI constructs StringVars in tests
-        try:
-            if tk._default_root is None:
-                tk.Tk().withdraw()
-        except Exception:
-            pass
         app = TimeTrackerGUI()
         app.run()
     except Exception as e:
